@@ -268,7 +268,7 @@ static void read_names(struct analyser * a, int type) {
                 static const symbol c_len_lit[] = {
                     'l', 'e', 'n'
                 };
-                MOVE_TO_B(t->b, c_len_lit);
+                t->b = MOVE_TO_B(t->b, c_len_lit);
                 goto handle_as_name;
             }
             case c_lenof: {
@@ -279,7 +279,7 @@ static void read_names(struct analyser * a, int type) {
                 static const symbol c_lenof_lit[] = {
                     'l', 'e', 'n', 'o', 'f'
                 };
-                MOVE_TO_B(t->b, c_lenof_lit);
+                t->b = MOVE_TO_B(t->b, c_lenof_lit);
                 goto handle_as_name;
             }
             case c_name:
@@ -463,9 +463,33 @@ static struct node * read_AE(struct analyser * a, struct name * assigned_to, int
             t->token_held = true;
             return p;
         }
-        q = new_node(a, token);
-        q->left = p;
-        q->right = read_AE(a, assigned_to, b);
+        struct node * r = read_AE(a, assigned_to, b);
+        if (p->type == c_number && r->type == c_number) {
+            // Evaluate constant sub-expression.
+            q = new_node(a, c_number);
+            switch (token) {
+                case c_plus:
+                    q->number = p->number + r->number;
+                    break;
+                case c_minus:
+                    q->number = p->number - r->number;
+                    break;
+                case c_multiply:
+                    q->number = p->number * r->number;
+                    break;
+                case c_divide:
+                    q->number = p->number / r->number;
+                    break;
+                default:
+                    fprintf(stderr, "Unexpected AE operator %s\n",
+                            name_of_token(token));
+                    exit(1);
+            }
+        } else {
+            q = new_node(a, token);
+            q->left = p;
+            q->right = r;
+        }
         p = q;
     }
 }
@@ -860,8 +884,20 @@ static struct node * read_C(struct analyser * a) {
     struct tokeniser * t = a->tokeniser;
     int token = read_token(t);
     switch (token) {
-        case c_bra:
-            return read_C_list(a);
+        case c_bra: {
+            struct node * p = read_C_list(a);
+            if (p->type != c_bra) {
+                fprintf(stderr, "read_C_list returned unexpected type %s\n",
+                        name_of_token(p->type));
+                exit(1);
+            }
+            if (p->left && !p->left->right) {
+                // Replace a single entry command list with the command it
+                // contains in order to make subsequent optimisations easier.
+                p = p->left;
+            }
+            return p;
+        }
         case c_backwards:
             {
                 int mode = a->mode;
@@ -973,7 +1009,15 @@ static struct node * read_C(struct analyser * a) {
                 /* Handle newer $(AE REL_OP AE) syntax. */
                 struct node * n = read_AE(a, 0, 0);
                 read_token(t);
-                switch (t->token) {
+                int token = t->token;
+                switch (token) {
+                    case c_assign:
+                        count_error(a);
+                        fprintf(stderr, "%s:%d: Expected relational operator (did you mean '=='?)\n",
+				t->file, t->line_number);
+                        /* Assume it was == to try to avoid an error avalanche. */
+                        token = c_eq;
+                        /* FALLTHRU */
                     case c_eq:
                     case c_ne:
                     case c_gr:
@@ -981,9 +1025,40 @@ static struct node * read_C(struct analyser * a) {
                     case c_ls:
                     case c_le: {
                         struct node * lhs = n;
-                        n = new_node(a, t->token);
-                        n->left = lhs;
-                        n->AE = read_AE(a, 0, 0);
+                        struct node * rhs = read_AE(a, 0, 0);
+                        if (lhs->type == c_number && rhs->type == c_number) {
+                            // Evaluate constant numeric test expression.
+                            int result;
+                            switch (token) {
+                                case c_eq:
+                                    result = (lhs->number == rhs->number);
+                                    break;
+                                case c_ne:
+                                    result = (lhs->number != rhs->number);
+                                    break;
+                                case c_gr:
+                                    result = (lhs->number > rhs->number);
+                                    break;
+                                case c_ge:
+                                    result = (lhs->number >= rhs->number);
+                                    break;
+                                case c_ls:
+                                    result = (lhs->number < rhs->number);
+                                    break;
+                                case c_le:
+                                    result = (lhs->number <= rhs->number);
+                                    break;
+                                default:
+                                    fprintf(stderr, "Unexpected numeric test operator %s\n",
+                                            name_of_token(t->token));
+                                    exit(1);
+                            }
+                            n = new_node(a, result ? c_true : c_false);
+                        } else {
+                            n = new_node(a, token);
+                            n->left = lhs;
+                            n->AE = rhs;
+                        }
                         get_token(a, c_ket);
                         break;
                     }
