@@ -39,7 +39,7 @@ def algorithms():
     if cext_available:
         return Stemmer.language()
     else:
-        return list(_languages.key())
+        return list(_languages.keys())
 
 def stemmer(lang):
     if cext_available:
